@@ -1,4 +1,3 @@
-use std::collections::BTreeMap;
 use std::sync::Arc;
 
 use futures_util::stream::{Stream, select_all};
@@ -18,11 +17,6 @@ pub use fluvio_spu_schema::server::stream_fetch::{
 use dataplane::Isolation;
 use dataplane::ReplicaKey;
 use dataplane::ErrorCode;
-use dataplane::fetch::DefaultFetchRequest;
-use dataplane::fetch::FetchPartition;
-use dataplane::fetch::FetchableTopic;
-use dataplane::fetch::FetchablePartitionResponse;
-use dataplane::record::RecordSet;
 use dataplane::batch::Batch;
 use fluvio_types::event::offsets::OffsetPublisher;
 
@@ -35,28 +29,7 @@ pub use dataplane::record::ConsumerRecord as Record;
 
 /// An interface for consuming events from a particular partition
 ///
-/// There are two ways to consume events: by "fetching" events
-/// and by "streaming" events. Fetching involves specifying a
-/// range of events that you want to consume via their [`Offset`].
-/// A fetch is a sort of one-time batch operation: you'll receive
-/// all of the events in your range all at once. When you consume
-/// events via Streaming, you specify a starting [`Offset`] and
-/// receive an object that will continuously yield new events as
-/// they arrive.
 ///
-/// # Creating a Consumer
-///
-/// You can create a `PartitionConsumer` via the [`partition_consumer`]
-/// method on the [`Fluvio`] client, like so:
-///
-/// ```
-/// # use fluvio::{Fluvio, Offset, ConsumerConfig, FluvioError};
-/// # async fn example(fluvio: &Fluvio) -> Result<(), FluvioError> {
-/// let consumer = fluvio.partition_consumer("my-topic", 0).await?;
-/// let records = consumer.fetch(Offset::beginning()).await?;
-/// # Ok(())
-/// # }
-/// ```
 ///
 /// [`Offset`]: struct.Offset.html
 /// [`partition_consumer`]: struct.Fluvio.html#method.partition_consumer
@@ -89,138 +62,6 @@ where
         self.partition
     }
 
-    /// Fetches events from a particular offset in the consumer's partition
-    ///
-    /// A "fetch" is one of the two ways to consume events in Fluvio.
-    /// It is a batch request for records from a particular offset in
-    /// the partition. You specify the position of records to retrieve
-    /// using an [`Offset`], and receive the events as a list of records.
-    ///
-    /// If you want more fine-grained control over how records are fetched,
-    /// check out the [`fetch_with_config`] method.
-    ///
-    /// # Example
-    ///
-    /// ```
-    /// # use fluvio::{PartitionConsumer, Offset, ConsumerConfig, FluvioError};
-    /// # async fn example(consumer: &PartitionConsumer) -> Result<(), FluvioError> {
-    /// let response = consumer.fetch(Offset::beginning()).await?;
-    /// for batch in response.records.batches {
-    ///     for record in batch.records() {
-    ///         let string = String::from_utf8_lossy(record.value.as_ref());
-    ///         println!("Got record: {}", string);
-    ///     }
-    /// }
-    /// # Ok(())
-    /// # }
-    /// ```
-    ///
-    /// [`Offset`]: struct.Offset.html
-    /// [`fetch_with_config`]: struct.PartitionConsumer.html#method.fetch_with_config
-    #[deprecated(note = "Use 'stream' instead", since = "0.9.2")]
-    #[instrument(skip(self, offset))]
-    pub async fn fetch(
-        &self,
-        offset: Offset,
-    ) -> Result<FetchablePartitionResponse<RecordSet>, FluvioError> {
-        let config = ConsumerConfig::builder().build()?;
-        #[allow(deprecated)]
-        let records = self.fetch_with_config(offset, config).await?;
-        Ok(records)
-    }
-
-    /// Fetches events from a consumer using a specific fetching configuration
-    ///
-    /// Most of the time, you shouldn't need to use a custom [`ConsumerConfig`].
-    /// If you don't know what these settings do, try checking out the simpler
-    /// [`fetch`] method that uses the default fetching settings.
-    ///
-    /// A "fetch" is one of the two ways to consume events in Fluvio.
-    /// It is a batch request for records from a particular offset in
-    /// the partition. You specify the range of records to retrieve
-    /// using an [`Offset`] and a [`ConsumerConfig`], and receive
-    /// the events as a list of records.
-    ///
-    /// # Example
-    ///
-    /// ```
-    /// # use fluvio::{PartitionConsumer, FluvioError, Offset, ConsumerConfig};
-    /// # async fn example(consumer: &PartitionConsumer) -> Result<(), FluvioError> {
-    /// // Use custom fetching configurations
-    /// let fetch_config = ConsumerConfig::builder()
-    ///     .max_bytes(1000)
-    ///     .build()?;
-    ///
-    /// let response = consumer.fetch_with_config(Offset::beginning(), fetch_config).await?;
-    /// for batch in response.records.batches {
-    ///     for record in batch.records() {
-    ///         let string = String::from_utf8_lossy(record.value.as_ref());
-    ///         println!("Got record: {}", string);
-    ///     }
-    /// }
-    /// # Ok(())
-    /// # }
-    /// ```
-    ///
-    /// [`ConsumerConfig`]: struct.ConsumerConfig.html
-    /// [`fetch`]: struct.PartitionConsumer.html#method.fetch
-    /// [`Offset`]: struct.Offset.html
-    #[deprecated(note = "Use 'stream_with_config' instead", since = "0.9.2")]
-    #[instrument(skip(self, offset, option))]
-    pub async fn fetch_with_config(
-        &self,
-        offset: Offset,
-        option: ConsumerConfig,
-    ) -> Result<FetchablePartitionResponse<RecordSet>, FluvioError> {
-        let replica = ReplicaKey::new(&self.topic, self.partition);
-        debug!(
-            "starting fetch log once: {:#?} from replica: {}",
-            offset, &replica,
-        );
-
-        let mut leader = self.pool.create_serial_socket(&replica).await?;
-        let offsets = fetch_offsets(&mut leader, &replica).await?;
-        debug!("found spu leader {}", leader);
-        let offset = offset.resolve(&offsets).await?;
-
-        let partition = FetchPartition {
-            partition_index: self.partition,
-            fetch_offset: offset,
-            max_bytes: option.max_bytes,
-            ..Default::default()
-        };
-
-        let topic_request = FetchableTopic {
-            name: self.topic.to_owned(),
-            fetch_partitions: vec![partition],
-        };
-
-        let fetch_request = DefaultFetchRequest {
-            topics: vec![topic_request],
-            isolation_level: option.isolation,
-            max_bytes: option.max_bytes,
-            ..Default::default()
-        };
-
-        let response = leader.send_receive(fetch_request).await?;
-
-        debug!("received fetch logs for {}", &replica);
-
-        if let Some(partition_response) = response.find_partition(&self.topic, self.partition) {
-            debug!(
-                "found partition response with: {} batches: {} bytes",
-                partition_response.records.batches.len(),
-                bytes_count(&partition_response.records)
-            );
-            Ok(partition_response)
-        } else {
-            Err(FluvioError::PartitionNotFound(
-                self.topic.clone(),
-                self.partition,
-            ))
-        }
-    }
-
     /// Continuously streams events from a particular offset in the consumer's partition
     ///
     /// Streaming is one of the two ways to consume events in Fluvio.
@@ -685,21 +526,6 @@ mod publish_stream {
     }
 }
 
-/// compute total bytes in record set
-fn bytes_count(records: &RecordSet) -> usize {
-    records
-        .batches
-        .iter()
-        .map(|batch| {
-            batch
-                .records()
-                .iter()
-                .map(|record| record.value.len())
-                .sum::<usize>()
-        })
-        .sum()
-}
-
 /// MAX FETCH BYTES
 static MAX_FETCH_BYTES: Lazy<i32> = Lazy::new(|| {
     use std::env;
@@ -739,83 +565,6 @@ impl ConsumerConfigBuilder {
         })?;
         Ok(config)
     }
-
-    /// Adds a SmartModule filter to this ConsumerConfig
-    #[deprecated(note = "Use 'smartmodule' instead", since = "0.9.11")]
-    pub fn wasm_filter<T: Into<Vec<u8>>>(
-        &mut self,
-        filter: T,
-        params: BTreeMap<String, String>,
-    ) -> &mut Self {
-        self.wasm_module(LegacySmartModulePayload {
-            wasm: SmartModuleWasmCompressed::Raw(filter.into()),
-            kind: SmartModuleKind::Filter,
-            params: params.into(),
-        });
-        self
-    }
-
-    /// Adds a SmartModule map to this ConsumerConfig
-    #[deprecated(note = "Use 'smartmodule' instead", since = "0.9.11")]
-    pub fn wasm_map<T: Into<Vec<u8>>>(
-        &mut self,
-        map: T,
-        params: BTreeMap<String, String>,
-    ) -> &mut Self {
-        self.wasm_module(LegacySmartModulePayload {
-            wasm: SmartModuleWasmCompressed::Raw(map.into()),
-            kind: SmartModuleKind::Map,
-            params: params.into(),
-        });
-        self
-    }
-
-    /// Adds a SmartModule filter_map to this ConsumerConfig
-    #[deprecated(note = "Use 'smartmodule' instead", since = "0.9.11")]
-    pub fn wasm_filter_map<T: Into<Vec<u8>>>(
-        &mut self,
-        filter_map: T,
-        params: BTreeMap<String, String>,
-    ) -> &mut Self {
-        self.wasm_module(LegacySmartModulePayload {
-            wasm: SmartModuleWasmCompressed::Raw(filter_map.into()),
-            kind: SmartModuleKind::FilterMap,
-            params: params.into(),
-        });
-        self
-    }
-
-    /// Adds a SmartModule array_map to this ConsumerConfig
-    #[deprecated(note = "Use 'smartmodule' instead", since = "0.9.11")]
-    pub fn wasm_array_map<T: Into<Vec<u8>>>(
-        &mut self,
-        array_map: T,
-        params: BTreeMap<String, String>,
-    ) -> &mut Self {
-        self.wasm_module(LegacySmartModulePayload {
-            wasm: SmartModuleWasmCompressed::Raw(array_map.into()),
-            kind: SmartModuleKind::ArrayMap,
-            params: params.into(),
-        })
-    }
-
-    /// Set a WASM aggregator function and initial accumulator value
-    #[deprecated(note = "Use 'smartmodule' instead", since = "0.9.11")]
-    pub fn wasm_aggregate<T: Into<Vec<u8>>, U: Into<Vec<u8>>>(
-        &mut self,
-        aggregate: T,
-        accumulator: U,
-        params: BTreeMap<String, String>,
-    ) -> &mut Self {
-        self.wasm_module(LegacySmartModulePayload {
-            wasm: SmartModuleWasmCompressed::Raw(aggregate.into()),
-            kind: SmartModuleKind::Aggregate {
-                accumulator: accumulator.into(),
-            },
-            params: params.into(),
-        });
-        self
-    }
 }
 
 /// Strategy used to select which partitions and from which topics should be streamed by the [`MultiplePartitionConsumer`]
