@@ -82,14 +82,14 @@
 )]
 
 mod error;
-mod sockets;
+pub mod sockets;
 mod admin;
 mod fluvio;
 pub mod consumer;
 mod producer;
 mod offset;
 mod sync;
-mod spu;
+pub mod spu;
 
 pub mod config;
 
@@ -97,6 +97,7 @@ use tracing::instrument;
 pub use error::FluvioError;
 pub use config::FluvioConfig;
 pub use producer::{TopicProducer, RecordKey};
+
 pub use consumer::{
     PartitionConsumer, ConsumerConfig, MultiplePartitionConsumer, PartitionSelectionStrategy,
 };
@@ -105,6 +106,10 @@ pub use offset::Offset;
 pub use crate::admin::FluvioAdmin;
 pub use crate::fluvio::Fluvio;
 
+pub(crate) mod built_info {
+    include!(concat!(env!("OUT_DIR"), "/built.rs"));
+}
+
 /// The minimum VERSION of the Fluvio Platform that this client is compatible with.
 const MINIMUM_PLATFORM_VERSION: &str = "0.9.0";
 
@@ -200,6 +205,8 @@ pub async fn consumer<S: Into<String>>(
 /// re-export metadata from sc-api
 pub mod metadata {
 
+    pub use fluvio_sc_schema::AdminSpec;
+
     pub mod topic {
         pub use fluvio_sc_schema::topic::*;
     }
@@ -211,6 +218,15 @@ pub mod metadata {
     pub mod smartmodule {
         pub use fluvio_sc_schema::smartmodule::*;
     }
+
+    pub mod derivedstream {
+        pub use fluvio_sc_schema::derivedstream::*;
+    }
+
+    pub mod customspu {
+        pub use fluvio_sc_schema::customspu::*;
+    }
+
     pub mod spu {
         pub use fluvio_sc_schema::spu::*;
     }
