@@ -3,6 +3,7 @@ use std::collections::HashMap;
 
 use tracing::{debug, trace, instrument};
 use async_lock::Mutex;
+use async_trait::async_trait;
 
 use dataplane::ReplicaKey;
 use dataplane::api::Request;
@@ -17,14 +18,53 @@ use crate::sockets::Versions;
 
 const DEFAULT_STREAM_QUEUE_SIZE: usize = 10;
 
-struct SpuSocket {
+/// used for connectiong to spu
+#[cfg_attr(target_arch = "wasm32", async_trait(?Send))]
+#[cfg_attr(not(target_arch = "wasm32"), async_trait)]
+pub trait SpuDirectory {
+    /// Create request/response socket to SPU for a replica
+    ///
+    /// All sockets to same SPU use a single TCP connection.
+    /// First this looks up SPU address in SPU metadata and try to see if there is an existing TCP connection.
+    /// If not, it will create a new connection and creates socket to it
+    async fn create_serial_socket(
+        &self,
+        replica: &ReplicaKey,
+    ) -> Result<VersionedSerialSocket, FluvioError>;
+
+    /// create stream to leader replica
+    async fn create_stream_with_version<R: Request>(
+        &self,
+        replica: &ReplicaKey,
+        request: R,
+        version: i16,
+    ) -> Result<AsyncResponse<R>, FluvioError>
+    where
+        R: Sync + Send;
+}
+
+/// Stream Socket to SPU
+#[derive(Debug)]
+pub struct SpuSocket {
     config: Arc<ClientConfig>,
     socket: SharedMultiplexerSocket,
     versions: Versions,
 }
 
 impl SpuSocket {
-    async fn create_serial_socket(&mut self) -> VersionedSerialSocket {
+    pub fn new(
+        config: Arc<ClientConfig>,
+        socket: SharedMultiplexerSocket,
+        versions: Versions,
+    ) -> Self {
+        Self {
+            config,
+            socket,
+            versions,
+        }
+    }
+
+    pub async fn create_serial_socket(&mut self) -> VersionedSerialSocket {
         VersionedSerialSocket::new(
             self.socket.clone(),
             self.config.clone(),
@@ -32,11 +72,11 @@ impl SpuSocket {
         )
     }
 
-    fn is_stale(&self) -> bool {
+    pub fn is_stale(&self) -> bool {
         self.socket.is_stale()
     }
 
-    async fn create_stream_with_version<R: Request>(
+    pub async fn create_stream_with_version<R: Request>(
         &mut self,
         request: R,
         version: i16,
@@ -81,6 +121,7 @@ impl SpuPool {
         let spu = self.metadata.spus().look_up_by_id(leader).await?;
 
         debug!("connecting to spu: {}", spu.spec);
+
         let mut client_config = self.config.with_prefix_sni_domain(spu.key());
 
         let spu_addr = match spu.spec.public_endpoint_local {
@@ -103,31 +144,6 @@ impl SpuPool {
         })
     }
 
-    /// Create request/response socket to SPU for a replica
-    ///
-    /// All sockets to same SPU use a single TCP connection.
-    /// First this looks up SPU address in SPU metadata and try to see if there is an existing TCP connection.
-    /// If not, it will create a new connection and creates socket to it
-    #[instrument(skip(self, replica))]
-    pub async fn create_serial_socket(
-        &self,
-        replica: &ReplicaKey,
-    ) -> Result<VersionedSerialSocket, FluvioError> {
-        let partition_search = self.metadata.partitions().lookup_by_key(replica).await?;
-        let partition = if let Some(partition) = partition_search {
-            partition
-        } else {
-            return Err(FluvioError::PartitionNotFound(
-                replica.topic.to_string(),
-                replica.partition,
-            ));
-        };
-
-        let leader_id = partition.spec.leader;
-        let socket = self.create_serial_socket_from_leader(leader_id).await?;
-        Ok(socket)
-    }
-
     #[instrument(skip(self))]
     pub async fn create_serial_socket_from_leader(
         &self,
@@ -151,14 +167,59 @@ impl SpuPool {
         Ok(serial_socket)
     }
 
-    /// create stream to leader replica
+    pub async fn topic_exists<S: Into<String>>(&self, topic: S) -> Result<bool, FluvioError> {
+        let replica = ReplicaKey::new(topic, 0);
+        Ok(self
+            .metadata
+            .partitions()
+            .lookup_by_key(&replica)
+            .await?
+            .is_some())
+    }
+
+    pub fn shutdown(&mut self) {
+        self.metadata.shutdown();
+    }
+}
+
+#[cfg_attr(target_arch = "wasm32", async_trait(?Send))]
+#[cfg_attr(not(target_arch = "wasm32"), async_trait)]
+impl SpuDirectory for SpuPool {
+    /// Create request/response socket to SPU for a replica
+    ///
+    /// All sockets to same SPU use a single TCP connection.
+    /// First this looks up SPU address in SPU metadata and try to see if there is an existing TCP connection.
+    /// If not, it will create a new connection and creates socket to it
+    #[instrument(skip(self, replica))]
+    async fn create_serial_socket(
+        &self,
+        replica: &ReplicaKey,
+    ) -> Result<VersionedSerialSocket, FluvioError> {
+        let partition_search = self.metadata.partitions().lookup_by_key(replica).await?;
+        let partition = if let Some(partition) = partition_search {
+            partition
+        } else {
+            return Err(FluvioError::PartitionNotFound(
+                replica.topic.to_string(),
+                replica.partition,
+            ));
+        };
+
+        let leader_id = partition.spec.leader;
+        let socket = self.create_serial_socket_from_leader(leader_id).await?;
+        Ok(socket)
+    }
+
     #[instrument(skip(self, replica, request, version))]
-    pub async fn create_stream_with_version<R: Request>(
+    async fn create_stream_with_version<R: Request>(
         &self,
         replica: &ReplicaKey,
         request: R,
         version: i16,
-    ) -> Result<AsyncResponse<R>, FluvioError> {
+    ) -> Result<AsyncResponse<R>, FluvioError>
+    where
+        R: Sync + Send,
+    {
         let partition_search = self.metadata.partitions().lookup_by_key(replica).await?;
 
         let partition = if let Some(partition) = partition_search {
@@ -189,18 +250,4 @@ impl SpuPool {
 
         Ok(stream)
     }
-
-    pub async fn topic_exists<S: Into<String>>(&self, topic: S) -> Result<bool, FluvioError> {
-        let replica = ReplicaKey::new(topic, 0);
-        Ok(self
-            .metadata
-            .partitions()
-            .lookup_by_key(&replica)
-            .await?
-            .is_some())
-    }
-
-    pub fn shutdown(&mut self) {
-        self.metadata.shutdown();
-    }
 }
