@@ -1,6 +1,18 @@
+use std::convert::TryFrom;
+use std::convert::TryInto;
+use std::fmt::Display;
 use std::sync::Arc;
 
+use fluvio_protocol::Decoder;
+use fluvio_protocol::Encoder;
+use fluvio_sc_schema::AdminSpec;
+use fluvio_sc_schema::core::Spec;
+use fluvio_sc_schema::objects::Metadata;
 use fluvio_sc_schema::objects::ObjectApiWatchRequest;
+use fluvio_sc_schema::objects::ObjectApiWatchResponse;
+use fluvio_sc_schema::objects::WatchRequest;
+use fluvio_sc_schema::objects::WatchResponse;
+use fluvio_socket::AsyncResponse;
 use tracing::{debug, instrument};
 
 use fluvio_socket::SharedMultiplexerSocket;
@@ -10,6 +22,7 @@ use crate::metadata::topic::TopicSpec;
 use crate::metadata::spu::SpuSpec;
 use crate::metadata::partition::PartitionSpec;
 
+use super::CacheMetadataStoreObject;
 use super::controller::{MetadataSyncController, SimpleEvent};
 use super::StoreContext;
 
@@ -68,64 +81,58 @@ impl MetadataStores {
     /// start watch for spu
     #[instrument(skip(self))]
     pub async fn start_watch_for_spu(&self) -> Result<(), SocketError> {
-        use dataplane::api::RequestMessage;
-        use fluvio_sc_schema::objects::WatchRequest;
-
-        let watch_request: WatchRequest<SpuSpec> = WatchRequest::default();
-        let watch_req: ObjectApiWatchRequest = watch_request.into();
-        let mut req_msg = RequestMessage::new_request(watch_req);
-        req_msg.get_mut_header().set_api_version(self.watch_version);
-
-        debug!("create spu metadata stream");
-        let async_response = self.socket.create_stream(req_msg, 10).await?;
-
-        MetadataSyncController::<SpuSpec>::start(
-            self.spus.clone(),
-            async_response,
-            self.shutdown.clone(),
-        );
+        self.start_watch::<SpuSpec>(self.spus.clone()).await?;
 
         Ok(())
     }
 
     #[instrument(skip(self))]
     pub async fn start_watch_for_partition(&self) -> Result<(), SocketError> {
-        use dataplane::api::RequestMessage;
-        use fluvio_sc_schema::objects::WatchRequest;
-
-        debug!("start watch for partition");
-
-        let watch_request: WatchRequest<PartitionSpec> = WatchRequest::default();
-        let watch_req: ObjectApiWatchRequest = watch_request.into();
-        let req_msg = RequestMessage::new_request(watch_req);
-        let async_response = self.socket.create_stream(req_msg, 10).await?;
-
-        MetadataSyncController::<PartitionSpec>::start(
-            self.partitions.clone(),
-            async_response,
-            self.shutdown.clone(),
-        );
+        self.start_watch::<PartitionSpec>(self.partitions.clone())
+            .await?;
 
         Ok(())
     }
 
     #[instrument(skip(self))]
     pub async fn start_watch_for_topic(&self) -> Result<(), SocketError> {
+        self.start_watch::<TopicSpec>(self.topics.clone()).await?;
+
+        Ok(())
+    }
+
+    #[instrument(skip(self, store))]
+    async fn start_watch<S>(
+        &self,
+        store: StoreContext<S::WatchResponseType>,
+    ) -> Result<(), SocketError>
+    // same bounds as MetadataSyncController
+    where
+        S: AdminSpec + 'static + Sync + Send,
+        ObjectApiWatchRequest: From<WatchRequest<S>>,
+        AsyncResponse<ObjectApiWatchRequest>: Send,
+        S::WatchResponseType: Encoder + Decoder + Send + Sync,
+        <S::WatchResponseType as Spec>::Status: Sync + Send + Encoder + Decoder,
+        <S::WatchResponseType as Spec>::IndexKey: Display + Sync + Send,
+        <WatchResponse<S> as TryFrom<ObjectApiWatchResponse>>::Error: Display + Send,
+        CacheMetadataStoreObject<S::WatchResponseType>: TryFrom<Metadata<S::WatchResponseType>>,
+        WatchResponse<S>: TryFrom<ObjectApiWatchResponse>,
+        <Metadata<S::WatchResponseType> as TryInto<
+            CacheMetadataStoreObject<S::WatchResponseType>,
+        >>::Error: Display,
+    {
         use dataplane::api::RequestMessage;
         use fluvio_sc_schema::objects::WatchRequest;
 
-        debug!("start watch for topic");
-
-        let watch_request: WatchRequest<TopicSpec> = WatchRequest::default();
+        let watch_request: WatchRequest<S> = WatchRequest::default();
         let watch_req: ObjectApiWatchRequest = watch_request.into();
-        let req_msg = RequestMessage::new_request(watch_req);
+        let mut req_msg = RequestMessage::new_request(watch_req);
+        req_msg.get_mut_header().set_api_version(self.watch_version);
+
+        debug!(watch_version = self.watch_version, obj = %S::LABEL, "create metadata stream");
         let async_response = self.socket.create_stream(req_msg, 10).await?;
 
-        MetadataSyncController::<TopicSpec>::start(
-            self.topics.clone(),
-            async_response,
-            self.shutdown.clone(),
-        );
+        MetadataSyncController::<S>::start(store, async_response, self.shutdown.clone());
 
         Ok(())
     }
